@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: Window.c,v 1.39 2001/01/10 11:49:47 dk Exp $
+ * $Id: Window.c,v 1.40 2001/06/15 07:46:21 dk Exp $
  */
 
 #include "apricot.h"
@@ -547,7 +547,7 @@ Window_menuColorIndex( Handle self, Bool set, int index, Color color)
    if (( index < 0) || ( index > ciMaxId)) return clInvalid;
    if ( !set)
       return  var-> menuColor[ index];
-   if (( color < 0) && (( color & wcMask) == 0)) color |= wcMenu;
+   if ((( color & clSysFlag) != 0) && (( color & wcMask) == 0)) color |= wcMenu;
    var-> menuColor[ index] = color;
    if ( var-> menu) apc_menu_set_color( var-> menu, color, index);
    return clInvalid;
