@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: conv.c,v 1.7 2000/05/17 10:28:57 tobez Exp $
+ * $Id: conv.c,v 1.10 2001/07/25 14:21:28 dk Exp $
  */
 /* Created by Anton Berezin <tobez@plab.ku.dk> */
 #include "img_conv.h"
@@ -36,11 +36,11 @@ extern "C" {
 #define var (( PImage) self)
 
 #define minimum_ByteValue 0
-#define maximum_ByteValue UCHAR_MAX
-#define minimum_shortValue SHRT_MIN
-#define maximum_shortValue SHRT_MAX
-#define minimum_longValue LONG_MIN
-#define maximum_longValue LONG_MAX
+#define maximum_ByteValue 255
+#define minimum_ShortValue INT16_MIN
+#define maximum_ShortValue INT16_MAX
+#define minimum_LongValue INT32_MIN
+#define maximum_LongValue INT32_MAX
 
 #define macro_asis(SourceType,DestType)                                        \
 void ic_##SourceType##_##DestType( Handle self,                           \
@@ -237,65 +237,65 @@ void rs_##SourceType##_##DestType( Handle self,                                \
    }                                                                           \
 }
 
-// macro_int_int( Byte, short)
-// macro_int_int( Byte, long)
-// macro_int_int( short, long)
-// macro_int_int( short, Byte)
-// macro_int_int( long, short)
-// macro_int_int( long, Byte)
-// macro_float_float__int_float( float, double)
-// macro_float_float__int_float( double, float)
-// macro_float_float__int_float( Byte, float)
-// macro_float_float__int_float( Byte, double)
-// macro_float_float__int_float( short, float)
-// macro_float_float__int_float( short, double)
-// macro_float_float__int_float( long, float)
-// macro_float_float__int_float( long, double)
-// macro_float_int(float, Byte)
-// macro_float_int(float, short)
-// macro_float_int(float, long)
-// macro_float_int(double, Byte)
-// macro_float_int(double, short)
-// macro_float_int(double, long)
+/*  macro_int_int( Byte, Short)
+    macro_int_int( Byte, Long)
+    macro_int_int( Short, Long)
+    macro_int_int( Short, Byte)
+    macro_int_int( Long, Short)
+    macro_int_int( Long, Byte)
+    macro_float_float__int_float( float, double)
+    macro_float_float__int_float( double, float)
+    macro_float_float__int_float( Byte, float)
+    macro_float_float__int_float( Byte, double)
+    macro_float_float__int_float( Short, float)
+    macro_float_float__int_float( Short, double)
+    macro_float_float__int_float( Long, float)
+    macro_float_float__int_float( Long, double)
+    macro_float_int(float, Byte)
+    macro_float_int(float, Short)
+    macro_float_int(float, Long)
+    macro_float_int(double, Byte)
+    macro_float_int(double, Short)
+    macro_float_int(double, Long) */
 
 macro_int_int( Byte, Byte)
-macro_int_int( short, short)
-macro_int_int( long, long)
+macro_int_int( Short, Short)
+macro_int_int( Long, Long)
 macro_float_float__int_float( float, float)
 macro_float_float__int_float( double, double)
 
-macro_int_int( short, Byte)
-macro_int_int( long, Byte)
+macro_int_int( Short, Byte)
+macro_int_int( Long, Byte)
 macro_float_int(float, Byte)
 macro_float_int(double, Byte)
 
-macro_asis(Byte,short)
-macro_asis(Byte,long)
+macro_asis(Byte,Short)
+macro_asis(Byte,Long)
 macro_asis(Byte,float)
 macro_asis(Byte,double)
-macro_asis(short,Byte)
-macro_asis(short,long)
-macro_asis(short,float)
-macro_asis(short,double)
-macro_asis(long,Byte)
-macro_asis(long,short)
-macro_asis(long,float)
-macro_asis(long,double)
+macro_asis(Short,Byte)
+macro_asis(Short,Long)
+macro_asis(Short,float)
+macro_asis(Short,double)
+macro_asis(Long,Byte)
+macro_asis(Long,Short)
+macro_asis(Long,float)
+macro_asis(Long,double)
 macro_asis(float,Byte)
-macro_asis(float,short)
-macro_asis(float,long)
+macro_asis(float,Short)
+macro_asis(float,Long)
 macro_asis(float,double)
 macro_asis(double,Byte)
-macro_asis(double,short)
-macro_asis(double,long)
+macro_asis(double,Short)
+macro_asis(double,Long)
 macro_asis(double,float)
 
 macro_asis_complex(Byte,float)
 macro_asis_complex(Byte,double)
-macro_asis_complex(short,float)
-macro_asis_complex(short,double)   
-macro_asis_complex(long,float)   
-macro_asis_complex(long,double)   
+macro_asis_complex(Short,float)
+macro_asis_complex(Short,double)   
+macro_asis_complex(Long,float)   
+macro_asis_complex(Long,double)   
 macro_asis_complex(float,float)   
 macro_asis_complex(float,double)   
 macro_asis_complex(double,float)   
@@ -303,13 +303,13 @@ macro_asis_complex(double,double)
 
 macro_asis_revcomplex(double,double)
 macro_asis_revcomplex(double,float)
-macro_asis_revcomplex(double,long)
-macro_asis_revcomplex(double,short)
+macro_asis_revcomplex(double,Long)
+macro_asis_revcomplex(double,Short)
 macro_asis_revcomplex(double,Byte)
 macro_asis_revcomplex(float,double)
 macro_asis_revcomplex(float,float)
-macro_asis_revcomplex(float,long)
-macro_asis_revcomplex(float,short)
+macro_asis_revcomplex(float,Long)
+macro_asis_revcomplex(float,Short)
 macro_asis_revcomplex(float,Byte)
    
 #ifdef __cplusplus
