@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: img_conv.h,v 1.14 2000/10/18 11:58:16 tobez Exp $
+ * $Id: img_conv.h,v 1.17 2001/07/25 14:21:29 dk Exp $
  */
 
 #include "Image.h"
@@ -42,24 +42,24 @@ extern "C" {
 #endif
 
 
-// initializer routine
-extern void init_image_support();
+/* initializer routine */
+extern void init_image_support(void);
 
-// image basic routines
+/* image basic routines */
 extern void ic_stretch( int type, Byte * srcData, int srcW, int srcH, Byte * dstData, int w, int h, Bool xStretch, Bool yStretch);
 extern void ic_type_convert( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
 extern int  image_guess_type( int fd);
 extern Bool itype_supported( int type);
 extern Bool itype_importable( int type, int *newtype, void **from_proc, void **to_proc);
 
-// palette routines
+/* palette routines */
 extern void cm_init_colormap( void);
 extern void cm_reverse_palette( PRGBColor source, PRGBColor dest, int colors);
 extern void cm_squeeze_palette( PRGBColor source, int srcColors, PRGBColor dest, int destColors);
 extern Byte cm_nearest_color( RGBColor color, int palSize, PRGBColor palette);
 extern void cm_fill_colorref( PRGBColor fromPalette, int fromColorCount, PRGBColor toPalette, int toColorCount, Byte * colorref);
 
-// bitstroke conversion routines
+/* bitstroke conversion routines */
 extern void bc_mono_nibble( register Byte * source, register Byte * dest, register int count);
 extern void bc_mono_nibble_cr( register Byte * source, register Byte * dest, register int count, register Byte * colorref);
 extern void bc_mono_byte( register Byte * source, register Byte * dest, register int count);
@@ -99,22 +99,35 @@ extern void bc_rgb_byte( Byte * source, register Byte * dest, register int count
 extern void bc_rgb_byte_ht( Byte * source, register Byte * dest, register int count, int lineSeqNo);
 extern void bc_rgb_byte_ed( Byte * source, register Byte * dest, register int count);
 
-// bitstroke stretching types
+/* bitstroke stretching types */
 
 typedef void StretchProc( void * srcData, void * dstData, int w, int x, int absx, long step);
 typedef StretchProc *PStretchProc;
 
+#if !defined(sgi) || defined(__GNUC__)
 #pragma pack(1)
+#endif
 typedef union _Fixed {
    int32_t l;
+#if (BYTEORDER==0x4321) || (BYTEORDER==0x87654321)
+   struct {
+     int16_t  i;
+     uint16_t f;
+   } i;
+#else   
    struct {
      uint16_t f;
      int16_t  i;
    } i;
+#endif
 } Fixed;
+#if !defined(sgi) || defined(__GNUC__)
 #pragma pack()
+#endif
 
-// bitstroke stretching routines
+#define UINT16_PRECISION (1L<<(8*sizeof(uint16_t)))
+
+/* bitstroke stretching routines */
 extern void bs_mono_in( uint8_t * srcData, uint8_t * dstData, int w, int x, int absx, long step);
 extern void bs_nibble_in( uint8_t * srcData, uint8_t * dstData, int w, int x, int absx, long step);
 extern void bs_uint8_t_in( uint8_t * srcData, uint8_t * dstData, int w, int x, int absx, long step);
@@ -136,11 +149,11 @@ extern void bs_double_out( double * srcData, double * dstData, int w, int x, int
 extern void bs_Complex_out( Complex * srcData, Complex * dstData, int w, int x, int absx, long step);
 extern void bs_DComplex_out( DComplex * srcData, DComplex * dstData, int w, int x, int absx, long step);
 
-// bitstroke copy routines
+/* bitstroke copy routines */
 extern void bc_nibble_copy( Byte * source, Byte * dest, unsigned int from, unsigned int width);
 extern void bc_mono_copy( Byte * source, Byte * dest, unsigned int from, unsigned int width);
 
-// image conversion routines
+/* image conversion routines */
 extern void ic_mono_nibble_ictNone( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
 extern void ic_mono_byte_ictNone( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
 extern void ic_mono_graybyte_ictNone( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
@@ -178,33 +191,33 @@ extern void ic_rgb_byte_ictHalftone( Handle self, Byte * dstData, PRGBColor dstP
 extern void ic_rgb_byte_ictErrorDiffusion( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
 extern void ic_rgb_graybyte_ictNone( Handle self, Byte * dstData, PRGBColor dstPal, int dstType);
 
-extern void ic_Byte_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_Byte_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Byte_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Byte_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_Byte_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_Byte_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_float_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_float_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_float_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_float_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_double_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_double_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_double_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_double_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_double_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_double_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 
 extern void ic_Byte_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_Byte_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_short_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_long_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Short_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_Long_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_double_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_double_float_complex( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
@@ -212,28 +225,28 @@ extern void ic_double_double_complex( Handle self, Byte *dstData, PRGBColor dstP
 
 extern void ic_double_complex_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_double_complex_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_double_complex_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_double_complex_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_double_complex_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_double_complex_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_double_complex_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_complex_double( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_complex_float( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_float_complex_long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
-extern void ic_float_complex_short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_float_complex_Long( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
+extern void ic_float_complex_Short( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 extern void ic_float_complex_Byte( Handle self, Byte *dstData, PRGBColor dstPal, int dstType);
 
 
-// image resampling routines
+/* image resampling routines */
 extern void rs_Byte_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
-extern void rs_short_short( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
-extern void rs_long_long( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
+extern void rs_Short_Short( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
+extern void rs_Long_Long( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
 extern void rs_float_float( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
 extern void rs_double_double( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
-extern void rs_short_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
-extern void rs_long_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
+extern void rs_Short_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
+extern void rs_Long_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
 extern void rs_float_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
 extern void rs_double_Byte( Handle self, Byte * dstData, int dstType, double srcLo, double srcHi, double dstLo, double dstHi);
 
-// extra convertors
+/* extra convertors */
 extern void bc_irgb_rgb( Byte * source, Byte * dest, int count);
 extern void bc_ibgr_rgb( Byte * source, Byte * dest, int count);
 extern void bc_bgri_rgb( Byte * source, Byte * dest, int count);
@@ -244,13 +257,13 @@ extern void bc_rgb_ibgr( Byte * source, Byte * dest, int count);
 extern void bc_rgb_bgri( Byte * source, Byte * dest, int count);
 
 
-// misc
+/* misc */
 typedef void SimpleConvProc( Byte * srcData, Byte * dstData, int count);
 typedef SimpleConvProc *PSimpleConvProc;
 
 extern void ibc_repad( Byte * source, Byte * dest, int srcLineSize, int dstLineSize, int srcDataSize, int dstDataSize, int srcBPP, int dstBPP, void * bit_conv_proc);
 
-// internal maps
+/* internal maps */
 extern Byte     map_stdcolorref    [ 256];
 extern Byte     div51              [ 256];
 extern Byte     div17              [ 256];
@@ -266,7 +279,7 @@ extern Byte     map_halftone8x8_51 [  64];
 extern Byte     map_halftone8x8_64 [  64];
 
 
-// internal macros
+/* internal macros */
 
 #define dBCARGS                                                   \
    int i;                                                         \
@@ -279,7 +292,7 @@ extern Byte     map_halftone8x8_64 [  64];
    Byte * srcData = var->data;                                    \
    Byte colorref[ 256]
 
-#ifdef __BORLANDC__
+#if defined (__BORLANDC__) || ( defined (sgi) && !defined (__GNUC__))
 #define BCWARN
 #else
 #define BCWARN                                                   \
