@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc.c,v 1.31 2001/05/10 08:02:03 dk Exp $
+ * $Id: apc.c,v 1.32 2001/06/15 07:46:23 dk Exp $
  */
 /* Created by:
          Dmitry Karasik <dk@plab.ku.dk>
@@ -1015,7 +1015,7 @@ apc_widget_map_points( Handle self, Bool toScreen, int count, Point * points)
 Color
 apc_widget_map_color( Handle self, Color color)
 {
-   if ((color < 0) && (( color & wcMask) == 0)) color |= var widgetClass;
+   if ((( color & clSysFlag) != 0) && (( color & wcMask) == 0)) color |= var widgetClass;
    return remap_color( NULLHANDLE, color, true); 
 }   
 
