@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc_graphics.c,v 1.85 2001/04/30 15:15:38 dk Exp $
+ * $Id: apc_graphics.c,v 1.90 2001/07/27 09:10:56 dk Exp $
  */
 
 /***********************************************************/
@@ -35,10 +35,10 @@
 #include "unix/guts.h"
 #include "Image.h"
 
-#define SORT(a,b)	({ int swp; if ((a) > (b)) { swp=(a); (a)=(b); (b)=swp; }})
-#define REVERT(a)	({ XX-> size. y + XX-> menuHeight - (a) - 1; })
-#define SHIFT(a,b)	({ (a) += XX-> gtransform. x + XX-> btransform. x; \
-                           (b) += XX-> gtransform. y + XX-> btransform. y; })
+#define SORT(a,b)	{ int swp; if ((a) > (b)) { swp=(a); (a)=(b); (b)=swp; }}
+#define REVERT(a)	(XX-> size. y + XX-> menuHeight - (a) - 1)
+#define SHIFT(a,b)	{ (a) += XX-> gtransform. x + XX-> btransform. x; \
+                           (b) += XX-> gtransform. y + XX-> btransform. y; }
 #define REVERSE_BYTES_32(x) ((((x)&0xff)<<24) | (((x)&0xff00)<<8) | (((x)&0xff0000)>>8) | (((x)&0xff000000)>>24))
 #define REVERSE_BYTES_24(x) ((((x)&0xff)<<16) | ((x)&0xff00) | (((x)&0xff0000)>>8))
 #define REVERSE_BYTES_16(x) ((((x)&0xff)<<8 ) | (((x)&0xff00)>>8))
@@ -224,11 +224,11 @@ Unbuffered:
    apc_gp_set_color( self, XX-> saved_fore);
    apc_gp_set_back_color( self, XX-> saved_back);
    memcpy( XX-> saved_fill_pattern, XX-> fill_pattern, sizeof( FillPattern));
-   XX-> fill_pattern[0]++; // force 
+   XX-> fill_pattern[0]++; /* force  */
    apc_gp_set_fill_pattern( self, XX-> saved_fill_pattern);
 
    if ( !XX-> flags. reload_font && XX-> font && XX-> font-> id) {
-      // fprintf( stderr, "set font g: %s\n", XX-> font-> load_name);
+      /* fprintf( stderr, "set font g: %s\n", XX-> font-> load_name); */
       XSetFont( DISP, XX-> gc, XX-> font-> id);
       XCHECKPOINT;
    } else {
@@ -246,7 +246,11 @@ prima_cleanup_drawable_after_painting( Handle self)
          XSetRegion( DISP, XX-> gc, XX-> paint_region);
       } else {
          Region region = XCreateRegion();
-         XRectangle r = {-XX-> btransform. x, XX-> btransform. y,XX->bsize.x,XX->bsize.y};
+         XRectangle r;
+         r. x = -XX-> btransform. x;
+         r. y = XX-> btransform. y;
+         r. width = XX->bsize.x;
+         r. height = XX->bsize.y;
          XUnionRectWithRegion( &r, region, region);
          XSetRegion( DISP, XX-> gc, region);
          XDestroyRegion( region);
@@ -321,7 +325,7 @@ prima_make_brush( DrawableSysData * XX, int colorIndex)
             XSetFillStyle( DISP, XX-> gc, FillOpaqueStippled);
             XSetBackground( DISP, XX-> gc, XX-> fore. secondary);
             XX-> flags. brush_back = 0;
-         } else // failure
+         } else /* failure */
             XSetFillStyle( DISP, XX-> gc, FillSolid);
       } else 
          XSetFillStyle( DISP, XX-> gc, FillSolid);
@@ -345,21 +349,21 @@ prima_make_brush( DrawableSysData * XX, int colorIndex)
       }
    } else {
       switch ( colorIndex) {
-      case 0: // back mix
+      case 0: /* back mix */
          if ( XX-> back. balance) {
             p = prima_get_hatch( &guts. ditherPatterns[ XX-> back. balance]);
             if ( p) {
                XSetStipple( DISP, XX-> gc, p);
                XSetFillStyle( DISP, XX-> gc, FillOpaqueStippled);
                XSetBackground( DISP, XX-> gc, XX-> back. secondary);
-            } else  // failure
+            } else  /* failure */
                XSetFillStyle( DISP, XX-> gc, FillSolid);
          } else 
             XSetFillStyle( DISP, XX-> gc, FillSolid);
          XSetForeground( DISP, XX-> gc, XX-> back. primary);
          XX-> flags. brush_back = 0;
          break;
-      case 1: // fore mix
+      case 1: /* fore mix */
          if ( memcmp( XX-> fill_pattern, fillPatterns[fpEmpty], sizeof(FillPattern))==0)
             return false;
          if ( XX-> fore. balance) {
@@ -379,7 +383,7 @@ prima_make_brush( DrawableSysData * XX, int colorIndex)
             XX-> flags. brush_fore = 1;
          }
          break;
-      case 2: // fore mix with fill pattern
+      case 2: /* fore mix with fill pattern */
          if ( memcmp( XX-> fill_pattern, fillPatterns[fpEmpty], sizeof(FillPattern))==0)
             return false;
          if ( XX-> fore. balance ) {
@@ -460,6 +464,39 @@ arc_completion( double * angleStart, double * angleEnd, int * needFigure)
    return ( max % 2) ? 1 : 2;
 }
 
+static void
+calculate_ellipse_divergence(void)
+{
+   static Bool init = false;
+   if ( !init) {
+      XGCValues gcv;
+      Pixmap px = XCreatePixmap( DISP, guts.root, 4, 4, 1);
+      GC gc = XCreateGC( DISP, px, 0, &gcv);
+      XImage *xi;
+      XSetForeground( DISP, gc, 0);
+      XFillRectangle( DISP, px, gc, 0, 0, 5, 5);
+      XSetForeground( DISP, gc, 1);
+      XDrawArc( DISP, px, gc, 0, 0, 4, 4, 0, 360 * 64);
+      if (( xi = XGetImage( DISP, px, 0, 0, 4, 4, 1, XYPixmap))) {
+         int i;
+         Byte *data[4];
+         if ( xi-> bitmap_bit_order == LSBFirst) 
+            prima_mirror_bytes( xi-> data, xi-> bytes_per_line * 4);
+         for ( i = 0; i < 4; i++) data[i] = (Byte*)xi-> data + i * xi-> bytes_per_line;
+#define PIX(x,y) ((data[y][0] & (0x80>>(x)))!=0)
+         if (  PIX(2,1) && !PIX(3,1)) guts. ellipseDivergence.x = -1; else
+         if ( !PIX(2,1) && !PIX(3,1)) guts. ellipseDivergence.x = 1; 
+         if (  PIX(1,2) && !PIX(1,3)) guts. ellipseDivergence.y = -1; else
+         if ( !PIX(1,2) && !PIX(1,3)) guts. ellipseDivergence.y = 1; 
+#undef PIX                          
+         XDestroyImage( xi);
+      }
+      XFreeGC( DISP, gc);
+      XFreePixmap( DISP, px);
+      init = true;
+   }
+}
+
 #define ELLIPSE_RECT x - ( dX + 1) / 2 + 1, y - dY / 2, dX-guts.ellipseDivergence.x, dY-guts.ellipseDivergence.y
 #define FILL_ANTIDEFECT_REPAIRABLE \
       ( rop_map[XX-> paint_rop] == GXcopy ||\
@@ -491,6 +528,7 @@ apc_gp_arc( Handle self, int x, int y, int dX, int dY, double angleStart, double
    SHIFT( x, y);
    y = REVERT( y);
    PURE_FOREGROUND;
+   calculate_ellipse_divergence();
    compl = arc_completion( &angleStart, &angleEnd, &needf);
    while ( compl--)
       XDrawArc( DISP, XX-> gdrawable, XX-> gc, ELLIPSE_RECT, 0, 360 * 64);
@@ -533,7 +571,7 @@ apc_gp_clear( Handle self, int x1, int y1, int x2, int y2)
    SHIFT( x1, y1); SHIFT( x2, y2);
    SORT( x1, x2); SORT( y1, y2);
    
-   // clean color entries, leave just background & foreground. XXX
+   /* clean color entries, leave just background & foreground. XXX */
    if ( guts. dynamicColors && x1 <= 0 && x2 > XX-> size.x && y1 <= 0 && y2 >= XX-> size.y) {
       prima_palette_free(self,false);
       apc_gp_set_color(self, XX-> fore. color);
@@ -573,6 +611,7 @@ apc_gp_chord( Handle self, int x, int y, int dX, int dY, double angleStart, doub
    y = REVERT( y);
    PURE_FOREGROUND;
    compl = arc_completion( &angleStart, &angleEnd, &needf);
+   calculate_ellipse_divergence();
    while ( compl--)
       XDrawArc( DISP, XX-> gdrawable, XX-> gc, ELLIPSE_RECT, 0, 360 * 64);
    if ( !needf) return true;
@@ -652,6 +691,7 @@ apc_gp_ellipse( Handle self, int x, int y, int dX, int dY)
    SHIFT( x, y);
    y = REVERT( y);
    PURE_FOREGROUND;
+   calculate_ellipse_divergence();
    XDrawArc( DISP, XX-> gdrawable, XX-> gc, ELLIPSE_RECT, 0, 64*360);
    return true;
 }
@@ -1250,6 +1290,7 @@ apc_gp_sector( Handle self, int x, int y,  int dX, int dY, double angleStart, do
 
    compl = arc_completion( &angleStart, &angleEnd, &needf);
    PURE_FOREGROUND;
+   calculate_ellipse_divergence();
    while ( compl--)
       XDrawArc( DISP, XX-> gdrawable, XX-> gc, ELLIPSE_RECT,
           0, 360 * 64);
@@ -1380,14 +1421,14 @@ gp_text_out_rotated( Handle self, const char* text, int x, int y, int len)
   
       /* find reference point in pixmap */
       px = ( cs-> lbearing < 0) ? -cs-> lbearing : 0;
-      rx. l = px * r-> cos2. l - py * r-> sin2. l + 0x8000;
-      ry. l = px * r-> sin2. l + py * r-> cos2. l + 0x8000;
+      rx. l = px * r-> cos2. l - py * r-> sin2. l + UINT16_PRECISION/2;
+      ry. l = px * r-> sin2. l + py * r-> cos2. l + UINT16_PRECISION/2;
       psx = rx. i. i - r-> shift. x;
       psy = ry. i. i - r-> shift. y;
       
       /* find glyph position */
-      rx. l = ax * r-> cos2. l - ay * r-> sin2. l + 0x8000;
-      ry. l = ax * r-> sin2. l + ay * r-> cos2. l + 0x8000;
+      rx. l = ax * r-> cos2. l - ay * r-> sin2. l + UINT16_PRECISION/2;
+      ry. l = ax * r-> sin2. l + ay * r-> cos2. l + UINT16_PRECISION/2;
       dsx = x + rx. i. i - psx;
       dsy = REVERT( y + ry. i. i) + psy - r-> dimension. y + 1;
 
@@ -1410,31 +1451,31 @@ gp_text_out_rotated( Handle self, const char* text, int x, int y, int len)
       
       switch ( XX-> paint_rop) { /* XXX Limited set edition - either expand to full list or find new way to display bitmaps */
       case ropXorPut:  
-         XSetBackground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
+         XSetBackground( DISP, XX-> gc, 0);
          XSetFunction( DISP, XX-> gc, GXxor); 
          break;
       case ropOrPut:   
-         XSetBackground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
+         XSetBackground( DISP, XX-> gc, 0);
          XSetFunction( DISP, XX-> gc, GXor);
          break;
       case ropAndPut:  
-         XSetBackground( DISP, XX-> gc, WhitePixel( DISP, SCREEN));
+         XSetBackground( DISP, XX-> gc, 0xffffffff);
          XSetFunction( DISP, XX-> gc, GXand);
          break;
       case ropNotPut:   
       case ropBlackness:
-         XSetForeground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
-         XSetBackground( DISP, XX-> gc, WhitePixel( DISP, SCREEN));
+         XSetForeground( DISP, XX-> gc, 0);
+         XSetBackground( DISP, XX-> gc, 0xffffffff);
          XSetFunction( DISP, XX-> gc, GXand);
          break;
       case ropWhiteness:
-         XSetForeground( DISP, XX-> gc, WhitePixel( DISP, SCREEN));
-         XSetBackground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
+         XSetForeground( DISP, XX-> gc, 0xffffffff);
+         XSetBackground( DISP, XX-> gc, 0);
          XSetFunction( DISP, XX-> gc, GXor);
          break;   
       default:   
-         XSetForeground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
-         XSetBackground( DISP, XX-> gc, WhitePixel( DISP, SCREEN));
+         XSetForeground( DISP, XX-> gc, 0);
+         XSetBackground( DISP, XX-> gc, 0xffffffff);
          XSetFunction( DISP, XX-> gc, GXand);
       }
       XPutImage( DISP, XX-> gdrawable, XX-> gc, r-> map[index]-> image, 0, 0, dsx, dsy, r-> dimension.x, r-> dimension.y);
@@ -1448,12 +1489,12 @@ gp_text_out_rotated( Handle self, const char* text, int x, int y, int len)
          break;
       case ropNotPut:   
          XSetForeground( DISP, XX-> gc, XX-> fore. primary);
-         XSetBackground( DISP, XX-> gc, WhitePixel( DISP, SCREEN));
+         XSetBackground( DISP, XX-> gc, 0xffffffff);
          XSetFunction( DISP, XX-> gc, GXorInverted);
          goto DISPLAY;
       default:   
           XSetForeground( DISP, XX-> gc, XX-> fore. primary);
-          XSetBackground( DISP, XX-> gc, BlackPixel( DISP, SCREEN));
+          XSetBackground( DISP, XX-> gc, 0);
           XSetFunction( DISP, XX-> gc, GXor);
       DISPLAY:          
           XPutImage( DISP, XX-> gdrawable, XX-> gc, r-> map[index]-> image, 0, 0, dsx, dsy, r-> dimension.x, r-> dimension.y);
@@ -1739,10 +1780,15 @@ apc_gp_get_line_pattern( Handle self, unsigned char *dashes)
 Point
 apc_gp_get_resolution( Handle self)
 {
-   if ( self)
-      return (Point){X(self)-> resolution. x, X(self)-> resolution. y};
-   else
-      return (Point){guts.resolution.x, guts.resolution.y};
+   Point ret;
+   if ( self) {
+      ret.x = X(self)-> resolution.x;
+      ret.y = X(self)-> resolution.y;
+   } else {
+      ret.x = guts.resolution.x;
+      ret.y = guts.resolution.y;
+   }
+   return ret;
 }
 
 int
