@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc_misc.c,v 1.66 2001/06/14 08:55:51 dk Exp $
+ * $Id: apc_misc.c,v 1.70 2001/07/26 22:03:14 dk Exp $
  */
 
 /***********************************************************/
@@ -145,6 +145,42 @@ unix_rm_get_int( Handle self, XrmQuark class_detail, XrmQuark name_detail, int d
    return default_value;
 }
 
+void
+prima_font_pp2font( char * ppFontNameSize, PFont font)
+{
+   char * p = strchr( ppFontNameSize, '.');
+   int i;
+
+   memset( font, 0, sizeof( Font));
+   if ( p)
+   {
+      font-> size = atoi( ppFontNameSize);
+      p++;
+   } else {
+      font-> size = 16;
+      p = "Helv";
+   }
+   font-> width = font-> height = C_NUMERIC_UNDEF;
+   font-> direction = 0;
+   font-> pitch = fpDefault;
+   font-> style = fsNormal;
+   strcpy( font-> name, p);
+   p = font-> name;
+   for ( i = strlen( p) - 1; i >= 0; i--)
+   {
+      if ( p[ i] == '.')
+      {
+         if ( strcmp( "Italic",     &p[ i + 1]) == 0) font-> style |= fsItalic;
+         if ( strcmp( "Underscore", &p[ i + 1]) == 0) font-> style |= fsUnderlined;
+         if ( strcmp( "Strikeout",  &p[ i + 1]) == 0) font-> style |= fsStruckOut;
+         if ( strcmp( "Bold",       &p[ i + 1]) == 0) font-> style |= fsBold;
+         p[ i] = 0;
+      }
+   }
+   apc_font_pick( application, font, font);
+   font-> pitch = fpDefault;
+}
+
 Bool
 apc_fetch_resource( const char *className, const char *name,
                     const char *resClass, const char *res,
@@ -211,7 +247,7 @@ apc_fetch_resource( const char *className, const char *name,
             *((Color*)result) = X_COLOR_TO_RGB(clr);
             break;
          case frFont:
-            return false;
+            prima_font_pp2font( s, ( Font *) result);
             break;
          default:
             return false;
@@ -270,16 +306,6 @@ apc_component_fullname_changed_notify( Handle self)
 
 /* Cursor support */
 
-static XGCValues cursor_gcv = {
-   background: 0,
-   cap_style: CapButt,
-   clip_mask: None,
-   foreground: 0,
-   function: GXcopy,
-   line_width: 0,
-   subwindow_mode: ClipByChildren,
-};
-
 void
 prima_no_cursor( Handle self)
 {
@@ -296,7 +322,7 @@ prima_no_cursor( Handle self)
       w = XX-> cursor_size. x;
 
       prima_get_gc( XX);
-      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &cursor_gcv);
+      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &guts. cursor_gcv);
       XCHECKPOINT;
       XCopyArea( DISP, guts. cursor_save, XX-> udrawable, XX-> gc,
 		 0, 0, w, h, x, y);
@@ -323,8 +349,8 @@ prima_update_cursor( Handle self)
 	   || h > guts. cursor_pixmap_size. y)
       {
 	 if ( !guts. cursor_save) {
-	    cursor_gcv. background = BlackPixel( DISP, SCREEN);
-	    cursor_gcv. foreground = WhitePixel( DISP, SCREEN);
+	    guts. cursor_gcv. background = 0;
+	    guts. cursor_gcv. foreground = 0xffffffff;
 	 }
 	 if ( guts. cursor_save) {
 	    XFreePixmap( DISP, guts. cursor_save);
@@ -353,7 +379,7 @@ prima_update_cursor( Handle self)
       }
 
       prima_get_gc( XX);
-      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &cursor_gcv);
+      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &guts. cursor_gcv);
       XCHECKPOINT;
       XCopyArea( DISP, XX-> udrawable, guts. cursor_save, XX-> gc,
 		 x, y, w, h, 0, 0);
@@ -400,7 +426,7 @@ prima_cursor_tick( void)
       w = XX-> cursor_size. x;
 
       prima_get_gc( XX);
-      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &cursor_gcv);
+      XChangeGC( DISP, XX-> gc, VIRGIN_GC_MASK, &guts. cursor_gcv);
       XCHECKPOINT;
       XCopyArea( DISP, pixmap, XX-> udrawable, XX-> gc, 0, 0, w, h, x, y);
       XCHECKPOINT;
@@ -771,7 +797,7 @@ apc_show_message( const char * message)
    }   
    
    appSz = apc_application_get_size( nilHandle);
-   // acquiring message font and wrapping message text
+   /* acquiring message font and wrapping message text */
    {
       PCachedFont cf;
       PFontABC abc;
@@ -782,7 +808,7 @@ apc_show_message( const char * message)
       apc_font_pick( nilHandle, &f, &f);
       cf = prima_find_known_font( &f, false, false);
       if ( !cf || !cf-> id) {
-         warn( "UAF_007: internal error (cf:%08x)", (IntPtr)cf); /* the font was not cached, can't be */
+         warn( "UAF_007: internal error (cf:%08x)", (IV)cf); /* the font was not cached, can't be */
          warn( message);
          return false;
       }
@@ -804,7 +830,7 @@ apc_show_message( const char * message)
       md. widths  = malloc( twr. count * sizeof(int));
       md. lengths = malloc( twr. count * sizeof(int));
 
-      // find text extensions
+      /* find text extensions */
       max = 0;
       for ( i = 0; i < twr. count; i++) {
          md. widths[i] = XTextWidth( fs, wrapped[i], 
@@ -934,15 +960,15 @@ apc_sys_get_insert_mode( void)
 PFont
 apc_sys_get_msg_font( PFont f)
 {
-   /* XXX - resources */
-   return apc_font_default( f);
+   memcpy( f, &guts. default_msg_font, sizeof( Font));
+   return f;
 }
 
 PFont
 apc_sys_get_caption_font( PFont f)
 {
-   /* XXX - resources */
-   return apc_font_default( f);
+   memcpy( f, &guts. default_caption_font, sizeof( Font));
+   return f;
 }
 
 int
@@ -951,7 +977,7 @@ apc_sys_get_value( int v)  /* XXX one big XXX */
    switch ( v) {
    case svYMenu: {
       Font f;
-      apc_font_default( &f);
+      apc_menu_default_font( &f);
       return f. height + MENU_ITEM_GAP * 2;
    } 
    case svYTitleBar: /* XXX */ return 20;
@@ -1137,6 +1163,7 @@ apc_getdir( const char *dirname)
    if (( dh = opendir( dirname)) && (dirlist = plist_create( 50, 50))) {
       while (( de = readdir( dh))) {
 	 list_add( dirlist, (Handle)duplicate_string( de-> d_name));
+#if defined(DT_REG) && defined(DT_DIR)
 	 switch ( de-> d_type) {
 	 case DT_FIFO:	type = "fifo";	break;
 	 case DT_CHR:	type = "chr";	break;
@@ -1149,6 +1176,7 @@ apc_getdir( const char *dirname)
 	 case DT_WHT:	type = "wht";	break;
 #endif
 	 default:
+#endif 
                         snprintf( path, 2047, "%s/%s", dirname, de-> d_name);
                         type = nil;
                         if ( stat( path, &s) == 0) {
@@ -1166,7 +1194,9 @@ apc_getdir( const char *dirname)
                            }
                         }
                         if ( !type)     type = "unknown";
+#if defined(DT_REG) && defined(DT_DIR)
 	 }
+#endif
 	 list_add( dirlist, (Handle)duplicate_string( type));
       }
       closedir( dh);
@@ -1224,8 +1254,8 @@ Bool   apc_prn_create( Handle self) { return false; }
 Bool   apc_prn_destroy( Handle self) { return true; }
 Bool   apc_prn_select( Handle self, const char* printer) { return false; }
 char * apc_prn_get_selected( Handle self) { return nil; }
-Point  apc_prn_get_size( Handle self) { return (Point){0,0}; }
-Point  apc_prn_get_resolution( Handle self) { return (Point){0,0}; }
+Point  apc_prn_get_size( Handle self) { Point r = {0,0}; return r; }
+Point  apc_prn_get_resolution( Handle self) { Point r = {0,0}; return r; }
 char * apc_prn_get_default( Handle self) { return nil; }
 Bool   apc_prn_setup( Handle self) { return false; }
 Bool   apc_prn_begin_doc( Handle self, const char* docName) { return false; }
