@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: apc_widget.c,v 1.65 2001/05/08 14:15:21 dk Exp $
+ * $Id: apc_widget.c,v 1.70 2001/07/25 14:21:30 dk Exp $
  */
 
 /***********************************************************/
@@ -36,8 +36,8 @@
 #include "Window.h"
 #include "Application.h"
 
-#define SORT(a,b)       ({ int swp; if ((a) > (b)) { swp=(a); (a)=(b); (b)=swp; }})
-#define REVERT(a)	({ XX-> size. y + XX-> menuHeight - (a) - 1; })
+#define SORT(a,b)       { int swp; if ((a) > (b)) { swp=(a); (a)=(b); (b)=swp; }}
+#define REVERT(a)	( XX-> size. y + XX-> menuHeight - (a) - 1)
 
 Bool
 apc_widget_map_points( Handle self, Bool toScreen, int n, Point *p)
@@ -124,12 +124,12 @@ apc_widget_get_z_order( Handle self, int zOrderId)
             break;
          }   
       }   
-      if ( found < 0) { // if !clipOwner
+      if ( found < 0) { /* if !clipOwner */
          ret = self;
          goto EXIT; 
       }   
       i = found + inc;
-      if ( i < 0 || i >= count) goto EXIT; // last in line
+      if ( i < 0 || i >= count) goto EXIT; /* last in line */
    } else
       i = ( zOrderId == zoFirst) ? count - 1 : 0;
    
@@ -167,6 +167,43 @@ process_transparents( Handle self)
    }
 }
 
+static Bool
+flush_events( Display * disp, XEvent * ev, Handle self)
+{
+   XWindow win;
+   /* leave only configuration unrelated commands on the queue */
+   switch ( ev-> type) {
+   case SelectionRequest:
+   case SelectionClear:
+   case MappingNotify:
+   case SelectionNotify:
+   case ClientMessage:
+   case MapNotify:
+   case UnmapNotify:
+   case KeymapNotify:
+   case KeyPress:
+   case KeyRelease:
+   case PropertyNotify:
+   case ColormapNotify:
+   case DestroyNotify:
+      return false;
+   }
+
+   switch ( ev-> type) {
+   case ConfigureNotify:
+   case -ConfigureNotify:
+      win = ev-> xconfigure. window;
+      break;
+   case ReparentNotify:
+      win = ev-> xreparent. window;
+      break;
+   default:
+      win = ev-> xany. window;
+   }
+
+   return win == X_WINDOW;
+}
+
 Bool
 apc_widget_create( Handle self, Handle owner, Bool sync_paint,
 		   Bool clip_owner, Bool transparent, ApiHandle parentHandle)
@@ -215,6 +252,7 @@ apc_widget_create( Handle self, Handle owner, Bool sync_paint,
 
    if ( reset) {
       Point pos = PWidget(self)-> pos;
+      XEvent dummy_ev;
       if ( guts. currentMenu && PComponent( guts. currentMenu)-> owner == self) prima_end_menu();
       CWidget( self)-> end_paint_info( self);
       CWidget( self)-> end_paint( self);
@@ -222,9 +260,16 @@ apc_widget_create( Handle self, Handle owner, Bool sync_paint,
          TAILQ_REMOVE( &guts.paintq, XX, paintq_link);
          XX-> flags. paint_pending = false;
       }
+      /* flush configure events */
+      XSync( DISP, false);
+      while ( XCheckIfEvent( DISP, &dummy_ev, (void*)flush_events, (XPointer)self));
+      
       XChangeWindowAttributes( DISP, X_WINDOW, CWWinGravity, &attrs);
       XReparentWindow( DISP, X_WINDOW, parent, pos. x, 
          X(owner)-> size.y + X(owner)-> menuHeight - pos. y - X(self)-> size. y);
+      XX-> ackOrigin = pos;
+      XX-> ackSize   = XX-> size;
+      XX-> flags. mapped = XX-> flags. want_visible;
       process_transparents( self);
       return true;
    }   
@@ -258,8 +303,9 @@ apc_widget_create( Handle self, Handle owner, Bool sync_paint,
    if ( XT_IS_WINDOW(X(owner)) && PWindow(owner)-> menu)
       XRaiseWindow( DISP, PComponent(PWindow(owner)-> menu)-> handle);
 
-   XX-> size = (Point){0,0};
-   XX-> ackOrigin = XX-> ackSize = ( Point){0,0};
+   XX-> size. x = XX-> size. y = 
+   XX-> ackOrigin. x = XX-> ackOrigin. y = 
+   XX-> ackSize. x = XX-> ackOrigin. y = 0;
 
    hash_store( guts.windows, &X_WINDOW, sizeof(X_WINDOW), (void*)self);
 
@@ -320,7 +366,9 @@ apc_widget_begin_paint( Handle self, Bool inside_on_paint)
       Point so = CWidget(owner)-> get_size( owner);
       XDrawable dc;
       Region region;
-      XRectangle xr = {0,0,sz.x,sz.y};
+      XRectangle xr = {0,0,0,0};
+      xr. width = sz.x;
+      xr. height = sz.y;
   
       CWidget(owner)-> begin_paint( owner);
       dc = X(owner)-> gdrawable;
@@ -396,7 +444,8 @@ apc_widget_destroy( Handle self)
 PFont
 apc_widget_default_font( PFont f)
 {
-   return apc_font_default( f);
+   memcpy( f, &guts. default_widget_font, sizeof( Font));
+   return f;
 }
 
 Bool
@@ -449,12 +498,18 @@ Rect
 apc_widget_get_invalid_rect( Handle self)
 {
    DEFXX;
+   Rect ret;
    XRectangle r;
-   if ( !XX-> invalid_region)
-      return (Rect){0,0,0,0};
+   if ( !XX-> invalid_region) {
+      Rect r = {0,0,0,0}; 
+      return r;
+   }
    XClipBox( XX-> invalid_region, &r);
-   return (Rect){r.x, XX-> size.y + XX-> menuHeight - r.height - r.y, 
-                 r.x + r.width, XX-> size.y + XX-> menuHeight - r.y};
+   ret. left = r.x;
+   ret. bottom = XX-> size.y + XX-> menuHeight - r.height - r.y; 
+   ret. right = r.x + r.width;
+   ret. top =  XX-> size.y + XX-> menuHeight - r.y;
+   return ret;
 }
 
 Point
@@ -462,6 +517,7 @@ apc_widget_get_pos( Handle self)
 {
    DEFXX;
    XWindow r;
+   Point ret;
    int x, y, w, h, d, b;
 
    if ( XX-> type. window) {
@@ -478,8 +534,9 @@ apc_widget_get_pos( Handle self)
    
    XGetGeometry( DISP, X_WINDOW, &r, &x, &y, &w, &h, &b, &d);
    XTranslateCoordinates( DISP, XX-> parentHandle, guts. root, x, y, &x, &y, &r);
-   y = DisplayHeight( DISP, SCREEN) - y - w; 
-   return ( Point) { x, y};    
+   ret. x = x;
+   ret. y = DisplayHeight( DISP, SCREEN) - y - w; 
+   return ret;
 }
 
 Bool
@@ -580,7 +637,7 @@ apc_widget_is_showing( Handle self)
    XWindowAttributes attrs;
    DEFXX;
 
-   if ( XX && XX-> flags. mapped
+   if ( XX  
 	&& XGetWindowAttributes( DISP, XX->udrawable, &attrs)
 	&& attrs. map_state == IsViewable)
       return true;
@@ -872,7 +929,8 @@ apc_widget_set_pos( Handle self, int x, int y)
    bzero( &e, sizeof( e));
    e. cmd = cmMove;
    e. gen. source = self;
-   XX-> origin = e. gen. P = (Point){x,y};
+   XX-> origin. x = e. gen. P. x = x;
+   XX-> origin. y = e. gen. P. y = y;
    y = X(XX-> owner)-> size. y + X(XX-> owner)-> menuHeight - XX-> size.y - y;
    if ( XX-> parentHandle) {
       XWindow cld;
@@ -974,7 +1032,8 @@ apc_widget_set_size( Handle self, int width, int height)
       return apc_window_set_client_size( self, width - rc. left - rc. right, height - rc. bottom - rc. top);
    }   
    
-   widg-> virtualSize = (Point){width,height};
+   widg-> virtualSize. x = width;
+   widg-> virtualSize. y = height;
 
    width = ( width > 0)
       ? (( width >= widg-> sizeMin. x)
@@ -1029,14 +1088,14 @@ apc_widget_set_size_bounds( Handle self, Point min, Point max)
       hints. flags = PMinSize | PMaxSize;
       if ( XX-> flags. sizeable) {
          hints. min_width  = min. x;
-         hints. min_height = min. y;
+         hints. min_height = min. y + XX-> menuHeight;
          hints. max_width  = max. x;
-         hints. max_height = max. y;
+         hints. max_height = max. y + XX-> menuHeight;
       } else {   
          hints. min_width  = XX-> size. x;
-         hints. min_height = XX-> size. y;
+         hints. min_height = XX-> size. y + XX-> menuHeight;
          hints. max_width  = XX-> size. x;
-         hints. max_height = XX-> size. y;
+         hints. max_height = XX-> size. y + XX-> menuHeight;
       }
       XSetWMNormalHints( DISP, X_WINDOW, &hints);
       XCHECKPOINT;
